ISSM solver control parameters
issm_control(
solver = "nloptr",
algorithm = c("SLSQP", "AUGLAG/MMA", "AUGLAG/CCSAQ"),
trace = 0,
xtol_rel = 1e-14,
maxeval = 1000,
xtol_abs = 1e-12
)a list with the options which is then passed to the solver.
only ‘nloptr’ at present
(nloptr) the algorithm to use
(integer) controls print level information
(nloptr) relative tolerance on optimization parameters
(nloptr) number of function evaluations to stop on
(nloptr) absolute tolerances on optimization parameters
The function provides defaults for use, but additional control parameters may be appended to the list if the user so wishes (‘nloptr’ has many more options).